@@ -9,7 +9,6 @@ sub new
 {
   my($class, %args) = @_;
 
-  #if($^O eq 'MSWin32' || $^O eq 'solaris')
   if($^O eq 'MSWin32')
   {
     $args{alien_bin_requires}->{'Alien::libtool24'} = '0.02';
@@ -30,9 +29,19 @@ sub new
     $args{configure_requires}->{'Alien::Base'} = '0.024';
     $args{requires}->{'Alien::Base'} = '0.024';
   }
-  else
+  elsif($^O eq 'freebsd')
   {
-    $args{alien_helper} = {};
+    $args{alien_helper}->{star} = q{
+      join " ", File::Glob::bsd_glob("*")
+    };
+    unshift @{ $args{alien_build_commands} }, 
+      '%{patch} -p1 < ../../patches/freebsd-configure.diff',
+      '%{patch} -p1 < ../../patches/freebsd-autotools.diff',
+      '%{patch} -p1 < ../../patches/freebsd-iconv-const-arg2.diff',
+      # trick autotools into thinking that they do
+      # not need to regenerate (which is true)
+      'rm -f compile',
+      'touch %{star}';
   }
   
   my $self = $class->SUPER::new(%args);
